@@ -7,6 +7,9 @@ test_touch <- function() {
     touch(file)
     t2 <- file.mtime(file)
     RUnit::checkTrue(t1 < t2)
+    file <- file.path(tempfile(), "path", "not", "there.txt")
+    touch(file)
+    RUnit::checkTrue(file.exists(file))
 }
 if (interactive()) {
     test_touch()
